@@ -1,17 +1,3 @@
-/*
-  Racket
-  Copyright (c) 2004-2017 PLT Design Inc.
-  Copyright (c) 1995-2001 Matthew Flatt
-  All rights reserved.
-
-  Please see the full copyright in the documentation.
-
-  Originally based on:
-  libscheme
-  Copyright (c) 1994 Brent Benson
-  All rights reserved.
-*/
-
 typedef struct {
 /*========================================================================*/
 /*                       setjmpup (continuations)                         */
@@ -173,31 +159,16 @@ void (*scheme_log_warning)(char *buffer);
 void (*scheme_glib_log_message)(const char *log_domain, int log_level, const char *message, void *user_data);
 void *(*scheme_glib_log_message_test)(char *str);
 void (*scheme_out_of_memory_abort)();
-void (*scheme_wrong_count)(const char *name, int minc, int maxc,
-				  int argc, Scheme_Object **argv);
-void (*scheme_wrong_count_m)(const char *name, int minc, int maxc,
-				    int argc, Scheme_Object **argv,
-				    int is_method);
-void (*scheme_case_lambda_wrong_count)(const char *name, int argc,
-					      Scheme_Object **argv, int is_method, int count, ...);
-void (*scheme_wrong_type)(const char *name, const char *expected,
-				 int which, int argc,
-				 Scheme_Object **argv);
-void (*scheme_wrong_contract)(const char *name, const char *expected,
-                                     int which, int argc,
-                                     Scheme_Object **argv);
-void (*scheme_wrong_field_type)(Scheme_Object *c_name,
-				       const char *expected,
-				       Scheme_Object *o);
-void (*scheme_wrong_field_contract)(Scheme_Object *c_name,
-                                           const char *expected,
-                                           Scheme_Object *o);
+void (*scheme_wrong_count)(const char *name, int minc, int maxc, int argc, Scheme_Object **argv);
+void (*scheme_wrong_count_m)(const char *name, int minc, int maxc, int argc, Scheme_Object **argv, int is_method);
+void (*scheme_case_lambda_wrong_count)(const char *name, int argc, Scheme_Object **argv, int is_method, int count, ...);
+void (*scheme_wrong_type)(const char *name, const char *expected, int which, int argc, Scheme_Object **argv);
+void (*scheme_wrong_contract)(const char *name, const char *expected, int which, int argc, Scheme_Object **argv);
+void (*scheme_wrong_field_type)(Scheme_Object *c_name, const char *expected, Scheme_Object *o);
+void (*scheme_wrong_field_contract)(Scheme_Object *c_name, const char *expected, Scheme_Object *o);
 void (*scheme_arg_mismatch)(const char *name, const char *msg, Scheme_Object *o);
 void (*scheme_contract_error)(const char *name, const char *msg, ...);
-void (*scheme_wrong_return_arity)(const char *where,
-					 int expected, int got,
-					 Scheme_Object **argv,
-					 const char *context_detail, ...);
+void (*scheme_wrong_return_arity)(const char *where, int expected, int got, Scheme_Object **argv, const char *context_detail, ...);
 void (*scheme_unbound_global)(Scheme_Bucket *b);
 Scheme_Object *(*scheme_dynamic_wind)(void (*pre)(void *),
 					     Scheme_Object *(* volatile act)(void *),
@@ -300,14 +271,6 @@ Scheme_Object *(*scheme_extract_one_cc_mark_to_tag)(Scheme_Object *mark_set,
                                                            Scheme_Object *prompt_tag);
 /* Internal */
 Scheme_Object *(*scheme_do_eval)(Scheme_Object *obj, int _num_rands, Scheme_Object **rands, int val);
-Scheme_Object *(*scheme_eval_compiled_stx_string)(Scheme_Object *expr, Scheme_Env *env,
-							 intptr_t shift, Scheme_Object *modidx);
-Scheme_Object *(*scheme_load_compiled_stx_string)(const char *str, intptr_t len);
-Scheme_Object *(*scheme_compiled_stx_symbol)(Scheme_Object *stx);
-Scheme_Object *(*scheme_eval_compiled_sized_string)(const char *str, int len, Scheme_Env *env);
-Scheme_Object *(*scheme_eval_compiled_sized_string_with_magic)(const char *str, int len, Scheme_Env *env, 
-								      Scheme_Object *magic_symbol, Scheme_Object *magic_val,
-								      int multi_ok);
 void (*scheme_detach_multple_array)(Scheme_Object **a);
 /*========================================================================*/
 /*                           memory management                            */
@@ -794,7 +757,7 @@ int (*scheme_directory_exists)(char *dirname);
 char *(*scheme_expand_filename)(char* filename, int ilen, const char *errorin, int *ex, int guards);
 char *(*scheme_expand_user_filename)(char* filename, int ilen, const char *errorin, int *ex, int guards);
 char *(*scheme_expand_string_filename)(Scheme_Object *f, const char *errorin, int *ex, int guards);
-char *(*scheme_os_getcwd)(char *buf, int buflen, int *actlen, int noexn);
+char *(*scheme_os_getcwd)(char *buf, size_t buflen, int *actlen, int noexn);
 int (*scheme_os_setcwd)(char *buf, int noexn);
 char *(*scheme_getdrive)(void);
 Scheme_Object *(*scheme_split_path)(const char *path, int len, Scheme_Object **base, int *isdir, int kind);
@@ -845,28 +808,27 @@ Scheme_Object *(*scheme_read_byte_string)(Scheme_Object *port);
 Scheme_Object *(*scheme_make_namespace)(int argc, Scheme_Object *argv[]);
 void (*scheme_add_global)(const char *name, Scheme_Object *val, Scheme_Env *env);
 void (*scheme_add_global_symbol)(Scheme_Object *name, Scheme_Object *val,
-			      Scheme_Env *env);
+                                        Scheme_Env *env);
 Scheme_Object *(*scheme_make_envunbox)(Scheme_Object *value);
 Scheme_Object *(*scheme_lookup_global)(Scheme_Object *symbol, Scheme_Env *env);
 Scheme_Bucket *(*scheme_global_bucket)(Scheme_Object *symbol, Scheme_Env *env);
-Scheme_Bucket *(*scheme_global_keyword_bucket)(Scheme_Object *symbol, Scheme_Env *env);
 Scheme_Bucket *(*scheme_module_bucket)(Scheme_Object *mod, Scheme_Object *var, int pos, Scheme_Env *env);
 Scheme_Object *(*scheme_builtin_value)(const char *name); /* convenience */
 void (*scheme_set_global_bucket)(char *proc, Scheme_Bucket *var, Scheme_Object *val,
                                         int set_undef);
-void (*scheme_install_macro)(Scheme_Bucket *b, Scheme_Object *v);
-void (*scheme_save_initial_module_set)(Scheme_Env *env);
 Scheme_Env *(*scheme_primitive_module)(Scheme_Object *name, Scheme_Env *for_env);
 void (*scheme_finish_primitive_module)(Scheme_Env *env);
 void (*scheme_set_primitive_module_phaseless)(Scheme_Env *env, int phaseless);
 void (*scheme_protect_primitive_provide)(Scheme_Env *env, Scheme_Object *name);
 Scheme_Object *(*scheme_make_modidx)(Scheme_Object *path,
-				  Scheme_Object *base,
-				  Scheme_Object *resolved);
-Scheme_Object *(*scheme_apply_for_syntax_in_env)(Scheme_Object *proc, Scheme_Env *env);
+                                            Scheme_Object *base,
+                                            Scheme_Object *resolved);
 Scheme_Object *(*scheme_dynamic_require)(int argc, Scheme_Object *argv[]);
+Scheme_Object *(*scheme_dynamic_require_reader)(int argc, Scheme_Object *argv[]);
 Scheme_Object *(*scheme_namespace_require)(Scheme_Object *);
 int (*scheme_is_module_path)(Scheme_Object *);
+int (*scheme_is_module_path_index)(Scheme_Object *);
+int (*scheme_is_resolved_module_path)(Scheme_Object *);
 Scheme_Object *(*scheme_datum_to_kernel_stx)(Scheme_Object *e);
 int (*scheme_module_is_declared)(Scheme_Object *name, int try_load);
 /*========================================================================*/
@@ -971,7 +933,7 @@ Scheme_Object *(*scheme_make_late_weak_box)(Scheme_Object *v);
 Scheme_Object *(*scheme_make_ephemeron)(Scheme_Object *key, Scheme_Object *val);
 Scheme_Object *(*scheme_ephemeron_value)(Scheme_Object *o);
 Scheme_Object *(*scheme_ephemeron_key)(Scheme_Object *o);
-Scheme_Object *(*scheme_make_stubborn_will_executor)();
+Scheme_Object *(*scheme_make_late_will_executor)();
 Scheme_Object *(*scheme_load)(const char *file);
 Scheme_Object *(*scheme_load_extension)(const char *filename, Scheme_Env *env);
 void (*scheme_register_extension_global)(void *ptr, intptr_t size);
@@ -1005,6 +967,7 @@ Scheme_Object *(*scheme_malloc_key)(void);
 void (*scheme_free_key)(Scheme_Object *k);
 void *(*scheme_jit_find_code_end)(void *p);
 void (*scheme_jit_now)(Scheme_Object *f);
+void (*scheme_set_signal_handler)(int sig_id, Scheme_Signal_Handler_Proc proc);
 #ifndef SCHEME_EX_INLINE
 } Scheme_Extension_Table;
 #endif
